@@ -91,18 +91,18 @@ void R_outbreaker(unsigned char *DNAbinInput, int *Tcollec, int *n, int *nSeq, i
 
     /* COMPUTE PRIORS */
     double logPrior = logprior_all(par);
-    Rprintf("\nPrior value (log): %.10f\n", logPrior);/* fflush(stdout); */
+    /* Rprintf("\nPrior value (log): %.10f\n", logPrior);/\* fflush(stdout); *\/ */
 
    /* COMPUTE LIKELIHOOD */
     double logLike = loglikelihood_all(dat, dnaInfo, spatialInfo, gen, par, rng);
-    Rprintf("\n\n = Initial Log-likelihood value: %f\n", logLike);
+    /* Rprintf("\n\n = Initial Log-likelihood value: %f\n", logLike); */
 
     /* COMPUTE POSTERIOR */
     double logPost = logposterior_all(dat, dnaInfo, spatialInfo, gen, par, rng);
-    Rprintf("\nLog-posterior value: %.10f\n", logPost);/* fflush(stdout); */
+    /* Rprintf("\nLog-posterior value: %.10f\n", logPost);/\* fflush(stdout); *\/ */
 
     /* ALLOCATE AND INITIALIZE MCMC PARAMETERS */
-    Rprintf("\nBefore check init LL\n");/* fflush(stdout); */
+    /* Rprintf("\nBefore check init LL\n");/\* fflush(stdout); *\/ */
 
     mcmcPar = alloc_mcmc_param(N);
     init_mcmc_param(mcmcPar, par, dat, (bool) *moveMut, moveAlpha, moveKappa, (bool) *moveTinf, 
@@ -116,8 +116,8 @@ void R_outbreaker(unsigned char *DNAbinInput, int *Tcollec, int *n, int *nSeq, i
       warning("\n\n!WARNING! Initial state of the chain has a likelihood of zero. The chain may never converge. Please consider using a different initial tree.\n");
     }
 
-    Rprintf("\nAfter check init LL\n");/* fflush(stdout); */
-    Rprintf("\nBefore MCMC\n");/* fflush(stdout); */
+    /* Rprintf("\nAfter check init LL\n");/\* fflush(stdout); *\/ */
+    /* Rprintf("\nBefore MCMC\n");/\* fflush(stdout); *\/ */
 
     /* RUN MCMC */
     mcmc(*nIter, *outputEvery, *resFileName, *tuneFileName, *tuneEvery,
